@@ -1,37 +1,31 @@
-"""Creates challenge space in Synapse
-
-Input:  Challenge Project name
-Output: The skeleton for two challenges site with initial wiki, four teams
-        (admin, participants, organizers, and preregistrants), and
-        a challenge widget added on live site with a participant
-        team associated with it.
+"""The skeleton for two challenges site with initial wiki, four teams
+(admin, participants, organizers, and preregistrants), and
+a challenge widget added on live site with a participant
+team associated with it.
 
 For more information on challenges administration:
 https://docs.synapse.org/articles/challenge_administration.html
 
-Example (run on bash)
+Example::
 
->>> challengeutils createchallenge "Plouf Challenge"
+    import challengeutils
+    import synapseclient
+    syn = synapseclient.login()
+    challengeutils.createchallenge.main(syn, "Plouf Challenge")
 
-TODO Add participants
-TODO Add tests
 """
 import logging
 import sys
 
 import synapseclient
-try:
-    from synapseclient.core.exceptions import SynapseHTTPError
-except ModuleNotFoundError:
-    # For synapseclient < v2.0
-    from synapseclient.exceptions import SynapseHTTPError
+from synapseclient.core.exceptions import SynapseHTTPError
 import synapseutils
 
-from . import utils
-from . import permissions
+from . import challenge, permissions, utils
 
 logger = logging.getLogger(__name__)
 
+# TODO: Add participants
 # A pre-defined wiki project is used as initial template for challenge sites.
 # To copy over the template synapseutils.copyWiki() function is used with
 # template id as source and new challenge project entity synId as destination.
@@ -153,12 +147,12 @@ def create_challenge_widget(syn, project_live, team_part_id):
         team_part_id: Synapse team id of participant team
     """
     try:
-        challenge = utils.create_challenge(syn, project_live, team_part_id)
-        logger.info("Created Challenge ({})".format(challenge.id))
+        chal_obj = challenge.create_challenge(syn, project_live, team_part_id)
+        logger.info("Created Challenge ({})".format(chal_obj.id))
     except SynapseHTTPError:
-        challenge = utils.get_challenge(syn, project_live)
-        logger.info("Fetched existing Challenge ({})".format(challenge.id))
-    return challenge
+        chal_obj = challenge.get_challenge(syn, project_live)
+        logger.info("Fetched existing Challenge ({})".format(chal_obj.id))
+    return chal_obj
 
 
 def _update_wikipage_string(wikipage_string, challengeid, teamid,
@@ -286,8 +280,8 @@ def main(syn, challenge_name, live_site=None):
     else:
         project_live = syn.get(live_site)
 
-    challenge = create_challenge_widget(syn, project_live,
-                                        teams['team_part_id'])
+    challenge_obj = create_challenge_widget(syn, project_live,
+                                            teams['team_part_id'])
     create_evaluation_queue(syn, '%s Project Submission' % challenge_name,
                             'Project Submission',
                             project_live.id)
@@ -309,7 +303,7 @@ def main(syn, challenge_name, live_site=None):
     for page in new_wikiids:
         wikipage = syn.getWiki(project_staging, page['id'])
         wikipage.markdown = _update_wikipage_string(wikipage.markdown,
-                                                    challenge.id,
+                                                    challenge_obj.id,
                                                     teams['team_part_id'],
                                                     challenge_name,
                                                     project_live.id)
